@@ -59,11 +59,8 @@ struct ly_in;
  *     example the *:operational* datastore is not necessarily valid and results of the NETCONF's \<get\> or \<get-config\>
  *     oprations used with filters will be incomplete (and thus invalid). This can be allowed using ::LYD_PARSE_ONLY,
  *     the ::LYD_PARSE_NO_STATE should be used for the data returned by \<get-config\> operation.
- * - ::lyd_parse_ext_data() is used for parsing configuration data trees defined inside extension instances, such as
- *   instances of yang-data extension specified in [RFC 8040](http://tools.ietf.org/html/rfc8040).
  * - ::lyd_parse_op() is used for parsing RPCs/actions, replies, and notifications. Even NETCONF rpc, rpc-reply, and
  *   notification messages are supported.
- * - ::lyd_parse_ext_op() is used for parsing RPCs/actions, replies, and notifications defined inside extension instances.
  *
  * Further information regarding the processing input instance data can be found on the following pages.
  * - @subpage howtoDataValidation
@@ -75,9 +72,7 @@ struct ly_in;
  * - ::lyd_parse_data_mem()
  * - ::lyd_parse_data_fd()
  * - ::lyd_parse_data_path()
- * - ::lyd_parse_ext_data()
  * - ::lyd_parse_op()
- * - ::lyd_parse_ext_op()
  */
 
 /**
@@ -160,32 +155,24 @@ struct ly_in;
                                                  modified manually. If this flag is used incorrectly (for unordered data),
                                                  the behavior is undefined and most functions executed with these
                                                  data will not work correctly. */
-#define LYD_PARSE_SUBTREE 0x400000          /**< Parse only the first child item along with any descendants, but no
-                                                 siblings. This flag is not required when parsing data which do not
-                                                 start at the schema root; for that purpose, use lyd_parse_data's parent
-                                                 argument.
-                                                 Also, a new return value ::LY_ENOT is returned if there is a sibling
-                                                 subtree following in the input data. Note that if validation is requested,
-                                                 only the newly parsed subtree is validated. This might result in
-                                                 an invalid datastore content. */
-#define LYD_PARSE_WHEN_TRUE 0x800000        /**< Mark all the parsed nodes dependend on a when condition with the flag
+#define LYD_PARSE_WHEN_TRUE 0x400000        /**< Mark all the parsed nodes dependend on a when condition with the flag
                                                  that means the condition was satisifed before. This allows for
                                                  auto-deletion of these nodes during validation. */
-#define LYD_PARSE_NO_NEW 0x1000000          /**< Do not set ::LYD_NEW (non-validated node flag) for any nodes. Use
+#define LYD_PARSE_NO_NEW 0x800000           /**< Do not set ::LYD_NEW (non-validated node flag) for any nodes. Use
                                                  when parsing validated data to skip some validation tasks and modify
                                                  some validation behavior (auto-deletion of cases). */
-#define LYD_PARSE_STORE_ONLY 0x2010000      /**< Similar to ::LYD_PARSE_ONLY but even type value restrictions will not
+#define LYD_PARSE_STORE_ONLY 0x01010000     /**< Similar to ::LYD_PARSE_ONLY but even type value restrictions will not
                                                  be checked (length, range, pattern, ...) and if a value can be stored,
                                                  it is. Calling separate validation on these data always checks all the
                                                  restrictions as well. */
-#define LYD_PARSE_JSON_NULL 0x4000000       /**< Allow using JSON empty value 'null' within JSON input, such nodes are
+#define LYD_PARSE_JSON_NULL 0x02000000      /**< Allow using JSON empty value 'null' within JSON input, such nodes are
                                                  silently skipped and treated as non-existent. By default, such values
                                                  are invalid. */
-#define LYD_PARSE_JSON_STRING_DATATYPES 0x8000000 /**< By default, JSON data values are expected to be in the correct
+#define LYD_PARSE_JSON_STRING_DATATYPES 0x04000000/**< By default, JSON data values are expected to be in the correct
                                                        format according to RFC 7951 based on their type. Using this
                                                        option the validation can be softened to accept boolean and
                                                        number type values enclosed in quotes. */
-#define LYD_PARSE_ANYDATA_STRICT 0x10000000 /**< Apply strict parsing (::LYD_PARSE_STRICT) also to anydata
+#define LYD_PARSE_ANYDATA_STRICT 0x08000000 /**< Apply strict parsing (::LYD_PARSE_STRICT) also to anydata
                                                 content. By default, unknown elements in anydata are parsed
                                                 as opaque nodes. With this flag, an error is raised for any unknown
                                                 elements within anydata/anyxml subtrees. */
@@ -308,28 +295,6 @@ LIBYANG_API_DECL LY_ERR lyd_parse_data_fd(const struct ly_ctx *ctx, int fd, LYD_
 LIBYANG_API_DECL LY_ERR lyd_parse_data_path(const struct ly_ctx *ctx, const char *path, LYD_FORMAT format,
         uint32_t parse_options, uint32_t validate_options, struct lyd_node **tree);
 
-/**
- * @brief Parse (and validate) data from the input handler as an extension data tree following the schema tree of the given
- * extension instance.
- *
- * Note that the data being parsed are limited only to the schema tree specified by the given extension, it does not allow
- * to mix them with the standard data from any module.
- *
- * Directly applicable to data defined as [yang-data](@ref howtoDataYangdata).
- *
- * @param[in] ext Extension instance providing the specific schema tree to match with the data being parsed.
- * @param[in] parent Optional parent to connect the parsed nodes to.
- * @param[in] in The input handle to provide the dumped data in the specified @p format to parse (and validate).
- * @param[in] format Format of the input data to be parsed. Can be 0 to try to detect format from the input handler.
- * @param[in] parse_options Options for parser, see @ref dataparseroptions.
- * @param[in] validate_options Options for the validation phase, see @ref datavalidationoptions.
- * @param[out] tree Full parsed data tree, note that NULL can be a valid tree. If @p parent is set, set to NULL.
- * @return LY_SUCCESS in case of successful parsing (and validation).
- * @return LY_ERR value in case of error. Additional error information can be obtained from the context using ly_err* functions.
- */
-LIBYANG_API_DECL LY_ERR lyd_parse_ext_data(const struct lysc_ext_instance *ext, struct lyd_node *parent, struct ly_in *in,
-        LYD_FORMAT format, uint32_t parse_options, uint32_t validate_options, struct lyd_node **tree);
-
 /**
  * @brief Parse data from the input handler as a bare JSON value and connect it to the node parsed from the path.
  *
@@ -460,51 +425,6 @@ enum lyd_type {
 LIBYANG_API_DECL LY_ERR lyd_parse_op(const struct ly_ctx *ctx, struct lyd_node *parent, struct ly_in *in, LYD_FORMAT format,
         enum lyd_type data_type, uint32_t parse_options, struct lyd_node **tree, struct lyd_node **op);
 
-/**
- * @brief Parse extension data into an operation data tree following only the specification from the given extension instance.
- *
- * Directly applicable to data defined as [yang-data](@ref howtoDataYangdata).
- *
- * At least one of @p parent, @p tree, or @p op must always be set.
- *
- * Specific @p data_type values have different parameter meaning as follows:
- * - ::LYD_TYPE_RPC_NETCONF:
- *   - @p parent - must be NULL, the whole RPC is expected;
- *   - @p format - must be ::LYD_XML, NETCONF supports only this format;
- *   - @p tree - must be provided, all the NETCONF-specific XML envelopes will be returned here as
- *               a separate opaque data tree, even if the function fails, this may be returned;
- *   - @p op - must be provided, the RPC/action data tree itself will be returned here, pointing to the operation;
- *
- * - ::LYD_TYPE_NOTIF_NETCONF:
- *   - @p parent - must be NULL, the whole notification is expected;
- *   - @p format - must be ::LYD_XML, NETCONF supports only this format;
- *   - @p tree - must be provided, all the NETCONF-specific XML envelopes will be returned here as
- *               a separate opaque data tree, even if the function fails, this may be returned;
- *   - @p op - must be provided, the notification data tree itself will be returned here, pointing to the operation;
- *
- * - ::LYD_TYPE_REPLY_NETCONF:
- *   - @p parent - must be set, pointing to the invoked RPC operation (RPC or action) node;
- *   - @p format - must be ::LYD_XML, NETCONF supports only this format;
- *   - @p tree - must be provided, all the NETCONF-specific XML envelopes will be returned here as
- *               a separate opaque data tree, even if the function fails, this may be returned;
- *   - @p op - must be NULL, the reply is appended to the RPC;
- *   Note that there are 3 kinds of NETCONF replies - ok, error, and data. Only data reply appends any nodes to the RPC.
- *
- * @param[in] ext Extension instance providing the specific schema tree to match with the data being parsed.
- * @param[in] parent Optional parent to connect the parsed nodes to.
- * @param[in] in Input handle to read the input from.
- * @param[in] format Expected format of the data in @p in.
- * @param[in] data_type Expected operation to parse (@ref datatype).
- * @param[in] parse_options Options for parser are set based on @p data_type but either of ::LYD_PARSE_STRICT and
- * ::LYD_PARSE_OPAQ can be added, see @ref dataparseroptions.
- * @param[out] tree Optional full parsed data tree. If @p parent is set, set to NULL.
- * @param[out] op Optional pointer to the operation (action/RPC) node.
- * @return LY_ERR value.
- * @return LY_ENOT if @p data_type is a NETCONF message and the root XML element is not the expected one.
- */
-LIBYANG_API_DECL LY_ERR lyd_parse_ext_op(const struct lysc_ext_instance *ext, struct lyd_node *parent, struct ly_in *in,
-        LYD_FORMAT format, enum lyd_type data_type, uint32_t parse_options, struct lyd_node **tree, struct lyd_node **op);
-
 /**
  * @brief Validate a data subtree of an extension instance, which is assumed to be a separate data tree independent of
  * normal YANG data.
@@ -512,13 +432,12 @@ LIBYANG_API_DECL LY_ERR lyd_parse_ext_op(const struct lysc_ext_instance *ext, st
  * @param[in,out] ext_tree Ext data tree to validate. May be changed by validation, might become NULL.
  * @param[in] ext Extension instance whose data to validate.
  * @param[in] val_opts Validation options (@ref datavalidationoptions).
- * @param[in] dep_tree Tree to be used for validating references from the operation subtree.
  * @param[out] diff Optional diff with any changes made by the validation.
  * @return LY_SUCCESS on success.
  * @return LY_ERR error on error.
  */
 LIBYANG_API_DECL LY_ERR lyd_validate_ext(struct lyd_node **ext_tree, const struct lysc_ext_instance *ext,
-        uint32_t val_opts, const struct lyd_node *dep_tree, struct lyd_node **diff);
+        uint32_t val_opts, struct lyd_node **diff);
 
 /**
  * @brief Fully validate a data tree.
