@@ -1195,11 +1195,6 @@ schema_mount_validate(struct lysc_ext_instance *ext, struct lyd_node *node, cons
     ly_bool ext_data_free = 0;
     struct ly_set *ref_set = NULL;
 
-    if (!node) {
-        /* some data had to be parsed for this callback to be called */
-        EXT_LOGERR_INT_RET(NULL, ext);
-    }
-
     if (!(node->flags & LYD_EXT)) {
         /* no validation of the node with the mount-point */
         goto cleanup;
@@ -1210,6 +1205,12 @@ schema_mount_validate(struct lysc_ext_instance *ext, struct lyd_node *node, cons
         goto cleanup;
     }
     if (!ext_data) {
+        if (!strcmp(node->schema->module->name, "ietf-yang-library") ||
+                !strcmp(node->schema->module->name, "ietf-yang-schema-mount")) {
+            /* parsing operational data in the ext callback, recursively */
+            return lyd_validate_ext(&node, ext, 0, diff);
+        }
+
         /* ext data must have been provided */
         lyplg_ext_compile_log(NULL, ext, LY_LLERR, LY_EINVAL, "No ext data provided for schema mount validation.");
         ret = LY_EINVAL;
