@@ -1,9 +1,10 @@
 /**
  * @file tree_schema_internal.h
  * @author Radek Krejci <rkrejci@cesnet.cz>
+ * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief internal functions for YANG schema trees.
  *
- * Copyright (c) 2015 - 2024 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2026 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -53,7 +54,10 @@ extern const char * const ly_devmod_list[];
  * @param[in] PARENT parent statement where the KW is present - for logging.
  */
 #define PARSER_CHECK_STMTVER2_RET(CTX, KW, PARENT) \
-    if (PARSER_CUR_PMOD(CTX)->version < LYS_VERSION_1_1) {LOGVAL_PARSER((CTX), LY_VCODE_INCHILDSTMT2, KW, PARENT); return LY_EVALID;}
+    if (PARSER_CUR_PMOD(CTX)->version < LYS_VERSION_1_1) { \
+        LOGVAL_PARSER((CTX), LY_VCODE_INCHILDSTMT2, KW, PARENT); \
+        return LY_EVALID; \
+    }
 
 /* These 2 macros checks YANG's identifier grammar rule */
 #define is_yangidentstartchar(c) ((c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || c == '_')
@@ -126,7 +130,7 @@ enum yang_arg {
 
 #define PARSER_CUR_PMOD(CTX) ((struct lysp_module *)(CTX)->parsed_mods->objs[(CTX)->parsed_mods->count - 1])
 #define PARSER_CTX(CTX) ((CTX) ? PARSER_CUR_PMOD(CTX)->mod->ctx : NULL)
-#define LOGVAL_PARSER(CTX, ...) LOGVAL(PARSER_CTX(CTX), __VA_ARGS__)
+#define LOGVAL_PARSER(CTX, ...) LOGVAL(PARSER_CTX(CTX), NULL, __VA_ARGS__)
 
 struct lysp_ctx {
     LYS_INFORMAT format;             /**< parser format */
@@ -458,20 +462,55 @@ LY_ERR lysp_ext_find_definition(const struct ly_ctx *ctx, const struct lysp_ext_
 LY_ERR lysc_ext_find_definition(const struct ly_ctx *ctx, const struct lysp_ext_instance *ext, struct lysc_ext **ext_def);
 
 /**
- * @brief Get schema node in extension instance according to the given parameters.
+ * @brief Try to get schema node for data with a parent based on an extension instance.
  *
- * Wraps ::lys_getnext_ext() and match according to the given arguments.
- *
- * @param[in] ext Extension instance which top-level schema node is being searched.
- * @param[in] module Optional parameter to match the extension instance's (and its data) module.
- * @param[in] name Name of the schema node to find, if the string is not NULL-terminated, the @p name_len must be set.
- * @param[in] name_len Length of the @p name string, use in case the @p name is not NULL-terminated string.
- * @param[in] nodetype Allowed [type of the node](@ref schemanodetypes).
- * @param[in] options ORed [lys_getnext options](@ref sgetnextflags).
- * @return Found schema node if there is some satisfy the provided requirements.
+ * @param[in] ctx Context to use to search for @p mod.
+ * @param[in] mod Module to use, search in @p ctx if not set.
+ * @param[in] parent Parsed parent data node.
+ * @param[in] sparent Schema parent node.
+ * @param[in] prefix Node prefix, if any.
+ * @param[in] prefix_len Length of @p prefix.
+ * @param[in] format Format of @p prefix.
+ * @param[in] prefix_data Format-specific data.
+ * @param[in] name Node name.
+ * @param[in] name_len Length of @p name.
+ * @param[in] is_xpath Set if searching for nodes in an XPath expression.
+ * @param[out] snode Found schema node, NULL if no suitable was found.
+ * @param[out] ext Optional extension instance that provided @p snode.
+ * @return LY_SUCCESS on success;
+ * @return LY_ENOT if no extension instance parsed the data;
+ * @return LY_ERR on error.
  */
-const struct lysc_node *lysc_ext_find_node(const struct lysc_ext_instance *ext, const struct lys_module *module,
-        const char *name, size_t name_len, uint16_t nodetype, uint32_t options);
+LY_ERR lys_find_child_node_ext(const struct ly_ctx *ctx, const struct lys_module *mod, const struct lyd_node *parent,
+        const struct lysc_node *sparent, const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format,
+        void *prefix_data, const char *name, uint32_t name_len, ly_bool is_xpath, const struct lysc_node **snode,
+        struct lysc_ext_instance **ext);
+
+/**
+ * @brief Find a schema node of a parent, top-level in a module, or an extension.
+ *
+ * It may make sense to set both @p mod and @p prefix, module can be reused if already found but to make sure
+ * extension instance schema nodes match (different context), prefix is used for module checking.
+ *
+ * @param[in] ctx Context to use to search for node module.
+ * @param[in] parent Parent of the node, if any.
+ * @param[in] mod Module of the node. If not set, @p prefix is used.
+ * @param[in] prefix Module prefix, if any.
+ * @param[in] prefix_len Optional length of @p prefix, if not 0-terminated.
+ * @param[in] format Format of @p prefix.
+ * @param[in] prefix_data Format-specific data.
+ * @param[in] name Node name.
+ * @param[in] name_len Optional length of @p name, if not 0-terminated.
+ * @param[in] options ORed [lys_getnext options](@ref sgetnextflags).
+ * @param[out] snode Found schema node.
+ * @param[out] ext Optional ext instance of @p snode.
+ * @return LY_SUCCESS on success;
+ * @return LY_ENOT if not found;
+ * @return LY_ERR on error.
+ */
+LY_ERR lys_find_child_node(const struct ly_ctx *ctx, const struct lysc_node *parent, const struct lys_module *mod,
+        const char *prefix, uint32_t prefix_len, LY_VALUE_FORMAT format, void *prefix_data, const char *name,
+        uint32_t name_len, uint32_t options, const struct lysc_node **snode, struct lysc_ext_instance **ext);
 
 /**
  * @brief When the module comes from YIN format, the argument name is unknown because of missing extension definition
