@@ -73,7 +73,7 @@ test_searchdirs(void **state)
     /* removing searchpaths */
     /* nonexisting */
     assert_int_equal(LY_EINVAL, ly_ctx_unset_searchdir(UTEST_LYCTX, "/nonexistingfile"));
-    CHECK_LOG_CTX("Invalid argument value (ly_ctx_unset_searchdir()).", NULL, 0);
+    CHECK_LOG_CTX("Unable to normalize search directory \"/nonexistingfile\" (No such file or directory).", NULL, 0);
 
     /* first */
     assert_int_equal(LY_SUCCESS, ly_ctx_unset_searchdir(UTEST_LYCTX, path1));
@@ -145,7 +145,7 @@ test_searchdirs(void **state)
     /* removing searchpaths */
     /* nonexisting */
     assert_int_equal(LY_EINVAL, ly_ctx_unset_searchdir(UTEST_LYCTX, "/nonexistingfile"));
-    CHECK_LOG_CTX("Invalid argument value (ly_ctx_unset_searchdir()).", NULL, 0);
+    CHECK_LOG_CTX("Unable to normalize search directory \"/nonexistingfile\" (No such file or directory).", NULL, 0);
     /* first */
     assert_int_equal(LY_SUCCESS, ly_ctx_unset_searchdir(UTEST_LYCTX, TESTS_BIN "/utests"));
     assert_string_not_equal(TESTS_BIN "/utests", list[0]);
@@ -464,6 +464,20 @@ test_imports(void **state)
     ly_err_clean(UTEST_LYCTX, NULL);
 }
 
+static void
+test_includes(void **state)
+{
+    struct lys_module *mod;
+
+    ly_ctx_set_searchdir(UTEST_LYCTX, TESTS_DIR_MODULES_YANG);
+
+    /* load b with c and d submodules */
+    mod = ly_ctx_load_module(UTEST_LYCTX, "b", NULL, NULL);
+    assert_non_null(mod);
+
+    ly_ctx_unset_searchdir(UTEST_LYCTX, TESTS_DIR_MODULES_YANG);
+}
+
 static void
 test_get_models(void **state)
 {
@@ -476,7 +490,7 @@ test_get_models(void **state)
 
     unsigned int index = 0;
     const char *names[] = {
-        "ietf-yang-metadata", "yang", "default", "ietf-inet-types", "ietf-yang-types", "ietf-yang-schema-mount",
+        "ietf-inet-types", "ietf-yang-types", "ietf-yang-metadata", "yang", "default", "ietf-yang-schema-mount",
         "ietf-yang-structure-ext", "ietf-datastores", "ietf-yang-library", "a", "a", "a"
     };
 
@@ -504,8 +518,8 @@ test_get_models(void **state)
     mod2 = ly_ctx_get_module_implemented_ns(UTEST_LYCTX, mod->ns);
     assert_ptr_equal(mod, mod2);
     assert_non_null(ly_ctx_get_module(UTEST_LYCTX, "ietf-yang-metadata", "2016-08-05"));
-    assert_non_null(ly_ctx_get_module(UTEST_LYCTX, "ietf-yang-types", "2013-07-15"));
-    assert_non_null(ly_ctx_get_module(UTEST_LYCTX, "ietf-inet-types", "2013-07-15"));
+    assert_non_null(ly_ctx_get_module(UTEST_LYCTX, "ietf-yang-types", "2025-12-22"));
+    assert_non_null(ly_ctx_get_module(UTEST_LYCTX, "ietf-inet-types", "2025-12-22"));
     assert_non_null(ly_ctx_get_module_ns(UTEST_LYCTX, "urn:ietf:params:xml:ns:yang:ietf-datastores", "2018-02-14"));
 
     /* select module by revision */
@@ -1119,6 +1133,7 @@ main(void)
         UTEST(test_options),
         UTEST(test_models),
         UTEST(test_imports),
+        UTEST(test_includes),
         UTEST(test_get_models),
         UTEST(test_ylmem),
         UTEST(test_set_priv_parsed),
