@@ -1420,21 +1420,21 @@ test_plugin_store(void **state)
      */
     val_text = "20";
     assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &value, NULL, &err));
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, INT8, "20", 20);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     val_text = "-20";
     assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &value, NULL, &err));
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, INT8, "-20", -20);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     val_text = "0xf";
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "15", 15);
     assert_ptr_equal(value.realtype, lysc_type);
@@ -1442,7 +1442,7 @@ test_plugin_store(void **state)
 
     val_text = "1B";
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "27", 27);
     assert_ptr_equal(value.realtype, lysc_type);
@@ -1450,7 +1450,7 @@ test_plugin_store(void **state)
 
     val_text = "-0xf";
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "-15", -15);
     assert_ptr_equal(value.realtype, lysc_type);
@@ -1458,7 +1458,7 @@ test_plugin_store(void **state)
 
     val_text = "027";
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_OCTNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_OCTNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "23", 23);
     assert_ptr_equal(value.realtype, lysc_type);
@@ -1466,7 +1466,7 @@ test_plugin_store(void **state)
 
     val_text = "-027";
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_OCTNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_OCTNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "-23", -23);
     assert_ptr_equal(value.realtype, lysc_type);
@@ -1481,7 +1481,7 @@ test_plugin_store(void **state)
 
     memcpy(alloc, val_text, strlen(val_text) + 1);
     ly_ret = type->store(UTEST_LYCTX, lysc_type, alloc, strlen(val_text) * 8,
-            LYPLG_TYPE_STORE_DYNAMIC, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
+            LYPLG_TYPE_STORE_DYNAMIC, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
     alloc = NULL;
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "10", 10);
@@ -1492,7 +1492,7 @@ test_plugin_store(void **state)
     lysc_type_test.basetype = LY_TYPE_UINT8;
     val_text = "20";
     ly_ret = type->store(UTEST_LYCTX, &lysc_type_test, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_EINT, ly_ret);
     UTEST_LOG_CTX_CLEAN;
 
@@ -1502,28 +1502,28 @@ test_plugin_store(void **state)
     val_text = "";
     err = NULL;
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     ly_err_free(err);
 
     val_text = "";
     err = NULL;
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, 1 * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     ly_err_free(err);
 
     val_text = "10 b";
     err = NULL;
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     ly_err_free(err);
 
     val_text = "a";
     err = NULL;
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &value, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     ly_err_free(err);
 
@@ -1532,7 +1532,7 @@ test_plugin_store(void **state)
     err = NULL;
     ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
             LYPLG_TYPE_STORE_ONLY, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL,
-            NULL, &value, NULL, &err);
+            &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     type->free(UTEST_LYCTX, &value);
     ly_err_free(err);
@@ -1569,7 +1569,7 @@ test_plugin_compare(void **state)
     /* CREATE VALUES */
     for (unsigned int it = 0; it < sizeof(val_init) / sizeof(val_init[0]); it++) {
         ly_ret = type->store(UTEST_LYCTX, lysc_type, val_init[it], strlen(val_init[it]) * 8,
-                0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &(values[it]), NULL, &err);
+                0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &(values[it]), NULL, &err);
         assert_int_equal(LY_SUCCESS, ly_ret);
     }
 
@@ -1589,7 +1589,7 @@ test_plugin_compare(void **state)
     diff_type_text = "20";
     diff_type = ((struct lysc_node_leaf *)mod->compiled->data->next)->type;
     ly_ret = lysc_get_type_plugin(diff_type->plugin_ref)->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &diff_type_val, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &diff_type_val, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     assert_int_equal(LY_SUCCESS, type->compare(UTEST_LYCTX, &diff_type_val, &(values[0])));
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[1])));
@@ -1601,7 +1601,7 @@ test_plugin_compare(void **state)
     diff_type_text = "20";
     diff_type = ((struct lysc_node_leaf *)mod->compiled->data->next->next)->type;
     ly_ret = lysc_get_type_plugin(diff_type->plugin_ref)->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &diff_type_val, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &diff_type_val, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[0])));
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[1])));
@@ -1613,7 +1613,7 @@ test_plugin_compare(void **state)
     diff_type_text = "20";
     diff_type = ((struct lysc_node_leaf *)mod->compiled->data->next->next->next)->type;
     ly_ret = lysc_get_type_plugin(diff_type->plugin_ref)->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text) * 8,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &diff_type_val, NULL, &err);
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &diff_type_val, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[0])));
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[1])));
@@ -1646,7 +1646,7 @@ test_plugin_print(void **state)
     /* CREATE VALUES */
     for (unsigned int it = 0; it < sizeof(val_init) / sizeof(val_init[0]); it++) {
         ly_ret = type->store(UTEST_LYCTX, lysc_type, val_init[it], strlen(val_init[it]) * 8,
-                0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &(values[it]), NULL, &err);
+                0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &(values[it]), NULL, &err);
         assert_int_equal(LY_SUCCESS, ly_ret);
     }
 
@@ -1694,7 +1694,7 @@ test_plugin_dup(void **state)
     /* CREATE VALUES */
     for (unsigned int it = 0; it < sizeof(val_init) / sizeof(val_init[0]); it++) {
         ly_ret = type->store(UTEST_LYCTX, lysc_type[it % 2], val_init[it], strlen(val_init[it]) * 8,
-                0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &(values[it]), NULL, &err);
+                0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &(values[it]), NULL, &err);
         assert_int_equal(LY_SUCCESS, ly_ret);
     }
 
